==> d42_typing-0.0.2.tar.gz: d42_typing-0.0.2/tests/ext_types/test_pyi_dict_with_numeric.py <==
import app.modules as modules
from app.helpers import load_module_from_string

SCHEMA_NAME = 'TestDictNumericSchema'

CODE = '''\
from d42 import schema
from district42_exp_types.numeric import schema_numeric

TestDictNumericSchema = schema.dict({
    "id": schema_numeric.min(1),
    "first_name": schema.str,
})
'''

CODE_PYI = '''\
from typing import overload
from typing import Literal
from typing import TypedDict
from district42_exp_types.numeric import NumericSchema
from district42.types import StrSchema

class _D42MetaTestDictNumericSchema(type):

    @overload
    def __getitem__(cls, arg: Literal['id']) -> NumericSchema:
        pass

    @overload
    def __getitem__(cls, arg: Literal['first_name']) -> StrSchema:
        pass

    def __mod__(self, other):
        pass

    def __add__(self, other):
        pass

class TestDictNumericSchema(metaclass=_D42MetaTestDictNumericSchema):

    class type(TypedDict, total=False):
        id: NumericSchema.type
        first_name: StrSchema.type\
'''

CODE_BLAHBLAH_PYI = '''\
from typing import overload
from typing import Type
from test.module import TestDictNumericSchema

@overload
def fake(schema: Type[TestDictNumericSchema]) -> TestDictNumericSchema.type:
    pass\
'''


def test_dict_numeric_pyi():
    module = load_module_from_string('test', CODE)
    schema_value = getattr(module, SCHEMA_NAME)

    typed_module = modules.TypedModule('file_name')
    typed_module.generate(SCHEMA_NAME, schema_value)

    assert typed_module.get_printable_content() == CODE_PYI


def test_dict_numeric_pyi_blahblah():
    module = load_module_from_string('test.module', CODE)
    schema_value = getattr(module, SCHEMA_NAME)

    blahblha_module = modules.BlahBlahModule()
    blahblha_module.generate('test.module', SCHEMA_NAME, schema_value)

    assert blahblha_module.get_printable_content() == CODE_BLAHBLAH_PYI

==> d42_typing-1.0.0.tar.gz: d42_typing-1.0.0/tests/ext_types/test_pyi_dict_with_numeric.py <==
import app.modules as modules
from app.helpers import load_module_from_string

SCHEMA_NAME = 'TestDictNumericSchema'

CODE = '''\
from d42 import schema
from district42_exp_types.numeric import schema_numeric

TestDictNumericSchema = schema.dict({
    "id": schema_numeric.min(1),
    "first_name": schema.str,
})
'''

CODE_PYI = '''\
from typing import overload
from typing import Literal
from typing import TypedDict
from typing import Any
from d42.declaration.types import StrSchema

class _D42MetaTestDictNumericSchema(type):

    @overload
    def __getitem__(cls, arg: Literal['id']) -> Any:
        pass

    @overload
    def __getitem__(cls, arg: Literal['first_name']) -> StrSchema:
        pass

    def __mod__(self, other):
        pass

    def __add__(self, other):
        pass

class TestDictNumericSchema(metaclass=_D42MetaTestDictNumericSchema):

    class type(TypedDict, total=False):
        id: Any
        first_name: StrSchema.type\
'''

CODE_BLAHBLAH_PYI = '''\
from typing import overload
from typing import Type
from test.module import TestDictNumericSchema

@overload
def fake(schema: Type[TestDictNumericSchema]) -> TestDictNumericSchema.type:
    pass\
'''


def test_dict_numeric_pyi():
    module = load_module_from_string('test', CODE)
    schema_value = getattr(module, SCHEMA_NAME)

    typed_module = modules.TypedSchemaModule('file_name')
    typed_module.generate(SCHEMA_NAME, schema_value)

    assert typed_module.get_printable_content() == CODE_PYI


def test_dict_numeric_pyi_blahblah():
    module = load_module_from_string('test.module', CODE)
    schema_value = getattr(module, SCHEMA_NAME)

    blahblha_module = modules.FakeModule()
    blahblha_module.generate('test.module', SCHEMA_NAME, schema_value)

    assert blahblha_module.get_printable_content() == CODE_BLAHBLAH_PYI
